def seat_from_position(chart, row, col):
    """
    Find out if seat at given position is available
    Update seating chart (in place)
    Return string with message if the seat was available or not
    """

    price = chart[row - 1][col - 1]

    if price == 0:
        return "The seat is unavailable. Please choose another option."
    else:
        chart[row - 1][col - 1] = 0
        return (
            f"The seat in row {row} and column {col} has been purchased for {price} kr."
        )


def seat_from_price(chart, price):
    """
    Find available seat given a price
    Update seating chart (in place)
    Return string with message if there was an available
    seat with that price or not
    """

    for row, line in enumerate(chart):
        for col, seat in enumerate(line):
            if seat == price:
                chart[row][col] = 0
                return f"The seat in row {row + 1} and column {col + 1} has been purchased for {price} kr."

    return f"There is no available seat with that price. Please choose another option."


def print_chart(chart):
    """
    Print seating chart
    """

    print()
    for line in chart:
        print(f"{line[0]:>2}", end="")
        for seat in line[1:]:
            print(f"{seat:>3}", end="")
        print()
    print()


if __name__ == "__main__":

    seating_chart = [
        [10, 10, 10, 10, 10, 10, 10, 10, 10, 10],
        [10, 10, 10, 10, 10, 10, 10, 10, 10, 10],
        [10, 10, 10, 10, 10, 10, 10, 10, 10, 10],
        [10, 10, 20, 20, 20, 20, 20, 20, 10, 10],
        [10, 10, 20, 20, 20, 20, 20, 20, 10, 10],
        [10, 10, 20, 20, 20, 20, 20, 20, 10, 10],
        [20, 20, 30, 30, 40, 40, 30, 30, 20, 20],
        [20, 30, 30, 40, 50, 50, 40, 30, 30, 20],
        [30, 40, 50, 50, 50, 50, 50, 50, 40, 30],
    ]

    print("Welcome! Here you can purchase seats for the theatre.")
    print("Below are the prices for all the seats:")
    print_chart(seating_chart)
    print(
        """You can either specify a seat you would like to purchase,
or you can specify a price you want to pay for your seat.
You can buy as many seats as you like.\n"""
    )

    while True:
        option = input(
            "Type [s] to specify a seat, type [p] ito specify a price or type [q] to quit: "
        )

        if option == "q":
            break
        elif option == "s":
            row = int(input("Please specify row number (1-9): "))
            col = int(input("Please specify column number (1-10): "))
            print()
            print(seat_from_position(seating_chart, row, col))
        elif option == "p":
            price = int(input("Please specify a price: "))
            print()
            print(seat_from_price(seating_chart, price))
        else:
            print("Please type either [s], [p] or [q].")
            continue

        print()
        print("Below is the updated seating chart:")
        print_chart(seating_chart)
